{
  inputs,
  config,
  lib,
  pkgs,
  userName,
  ...
}: {
  # Bring in the hardware configuration
  imports = [
    /etc/nixos/hardware-configuration.nix
  ];

  # Enable flakes for NixOS
  nix.settings.experimental-features = ["nix-command" "flakes"];

  # Utilize systemd-boot
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  # Install and enable common graphics drivers
  hardware.opengl = {
    driSupport = true;
    extraPackages = with pkgs; [
      mesa_drivers
      libvdpau-va-gl
      libva
      libva-utils
      intel-vaapi-driver # for Intel
      intel-media-driver # for Intel
      rocm-opencl-icd # for AMD
    ];
  };

  # For systems with AMD graphics, this enables Vulkan on 32-bit applications
  # For 64-bit application, however, Vulkan is enabled by default
  hardware.graphics.driSupport32Bit = true;

  # For systems with AMD graphics, enable AMDVLK
  hardware.hardware = {
    extraPackages = with pkgs; [
      amdvlk
    ];
    extraPackages32 = with pkgs; [
      driversi686Linux
    ];
  };

  # Enable Bluetooth if present
  hardware.bluetooth.enable = true;

  # Set your timezone
  time.timeZone = "America/Detroit";

  # Enable Pipewire (sound)
  services.pipewire = {
    enable = true;
    pulse.enable = true;
  };

  # Enable touchpad
  services.libinput.enable = true;

  # Install packages to be installed system-wide
  environment.systemPackages = with pkgs; [
    vim
    neovim
    git
    wireguard-tools
    podman
    toolbox
    grim
    slurp
    playerctl
    light
    brightnessctl
    wttrbar
    cliphist
  ];

  # Install system-wide fonts
  fonts.packages = with pkgs; [
    noto-fonts
    noto-fonts-cjk
    noto-fonts-emoji
    liberation_ttf
    monaspace
    nerdfonts
  ];

  # Set the EDITOR global environment variable to neovim
  environment.variables.EDITOR = "nvim";

  # Enable OpenSSH
  services.openssh.enable = true;

  # Enable keyring
  services.gnome.gnome-keyring.enable = true;

  # Enable GnuPG
  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  # Enable SUID wrappers (some programs need them)
  programs.mtr.enable = true;

  # Enable Polkit
  security.polkit.enable = true;

  # Enable power management
  powerManagement = {
    enable = true;
    powertop.enable = false; # TODO: to be enabled on laptops
    cpuFreqGovernor = "performace";
  };

  # Enable Steam and open various firewall ports when applicable
  programs.steam = {
    enable = true;
    remotePlay.openFirewall = true;
    localNetworkGameTransfers = true;
  };

  # Add username to groups "wheel" and "video" - more may be added here later
  users.users.${userName}.extraGroups = ["wheel" "video"];

  # XDG stuff
  xdg = {
    portal = {
      enable = true;
      extraPortals = with pkgs; [
        xdg-desktop-portal-wlr
        xdg-desktop-portal-gtk
      ];
    };
  };

  # Firewall stuff not allowed in common user and network creation
  networking.firewall.enable = true; # VERY important, do not touch
  # networking.firewall.allowedTCPPorts = [];
  # networking.firewall.allowedUDPPorts = [];
  networking.networkmanager.enable = true; # Linux tool for managing network connections

  # Enable Flatpak (app containerization)
  services.flatpak.enable = true;
}
